pub struct CompileOpts {
pub optimize: u8,
pub debug_ranges: bool,
pub int_max_str_digits: usize,
pub allow_top_level_await: bool,
pub future_features: CodeFlags,
pub dont_imply_dedent: bool,
pub recursion_limit: usize,
}Fields
optimize: u8How optimized the bytecode output should be; any optimize > 0 does not emit assert statements
debug_ranges: boolInclude column info in bytecode (-X no_debug_ranges disables)
int_max_str_digits: usizeMaximum decimal integer literal digits, matching sys.int_info/default.
allow_top_level_await: boolAllow module-level await/async-for/async-with, matching PyCF_ALLOW_TOP_LEVEL_AWAIT.
future_features: CodeFlagsFuture compiler flags passed explicitly to compile(), matching cf_flags merge.
dont_imply_dedent: boolKeep single-input blocks incomplete until a terminating newline is seen.
recursion_limit: usizeRecursion limit used by compiler tree walks, matching Py_EnterRecursiveCall.