SymbolTable

Struct SymbolTable 

pub struct SymbolTable {
Show 17 fields pub name: String, pub typ: CompilerScope, pub line_number: u32, pub is_nested: bool, pub symbols: IndexMap<String, Symbol, RandomState>, pub sub_tables: Vec<SymbolTable>, pub next_sub_table: usize, pub varnames: Vec<String>, pub needs_class_closure: bool, pub needs_classdict: bool, pub can_see_class_scope: bool, pub is_generator: bool, pub comp_inlined: bool, pub annotation_block: Option<Box<SymbolTable>>, pub has_conditional_annotations: bool, pub future_annotations: bool, pub mangled_names: Option<IndexSet<String, RandomState>>,
}
Captures all symbols in the current scope, and has a list of sub-scopes in this scope.

Fields

name: String

The name of this symbol table. Often the name of the class or function.

typ: CompilerScope

The type of symbol table

line_number: u32

The line number in the source code where this symboltable begins.

is_nested: boolsymbols: IndexMap<String, Symbol, RandomState>

A set of symbols present on this scope level.

sub_tables: Vec<SymbolTable>

A list of sub-scopes in the order as found in the AST nodes.

next_sub_table: usize

Cursor pointing to the next sub-table to consume during compilation.

varnames: Vec<String>

Variable names in definition order (parameters first, then locals)

needs_class_closure: bool

Whether this class scope needs an implicit class cell

needs_classdict: bool

Whether this class scope needs an implicit classdict cell

can_see_class_scope: bool

Whether this type param scope can see the parent class scope

is_generator: bool

Whether this scope contains yield/yield from (is a generator function)

comp_inlined: bool

Whether this comprehension scope should be inlined (PEP 709) True for list/set/dict comprehensions in non-generator expressions

annotation_block: Option<Box<SymbolTable>>

PEP 649: Reference to annotation scope for this block Annotations are compiled as a separate __annotate__ function

has_conditional_annotations: bool

PEP 649: Whether this scope has conditional annotations (annotations inside if/for/while/etc. blocks or at module level)

future_annotations: bool

Whether from __future__ import annotations is active

mangled_names: Option<IndexSet<String, RandomState>>

Names of type parameters that should still be mangled in type param scopes. When Some, only names in this set are mangled; other names are left unmangled. Set on type param blocks for generic classes; inherited by non-class child scopes.

Implementations

Source

impl SymbolTable

pub fn scan_program( program: &ModModule, source_file: SourceFile, ) -> Result<Self, SymbolTableError>

pub fn scan_expr( expr: &ModExpression, source_file: SourceFile, ) -> Result<Self, SymbolTableError>

pub fn lookup(&self, name: &str) -> Option<&Symbol>